ref: Make vdl generation use Call instead of Context.

MultiPart: 1/6
Change-Id: Ie739b6bc4540474c8ec11c92aa147ad9793293f4
diff --git a/profiles/internal/ipc/benchmark/internal/server.go b/profiles/internal/ipc/benchmark/internal/server.go
index d65f35f..5228f5b 100644
--- a/profiles/internal/ipc/benchmark/internal/server.go
+++ b/profiles/internal/ipc/benchmark/internal/server.go
@@ -18,9 +18,9 @@
 	return payload, nil
 }
 
-func (i *impl) EchoStream(ctx benchmark.BenchmarkEchoStreamContext) error {
-	rStream := ctx.RecvStream()
-	sStream := ctx.SendStream()
+func (i *impl) EchoStream(call benchmark.BenchmarkEchoStreamServerCall) error {
+	rStream := call.RecvStream()
+	sStream := call.SendStream()
 	for rStream.Advance() {
 		sStream.Send(rStream.Value())
 	}
diff --git a/profiles/internal/ipc/stress/internal/server.go b/profiles/internal/ipc/stress/internal/server.go
index 3cab901..1dbc300 100644
--- a/profiles/internal/ipc/stress/internal/server.go
+++ b/profiles/internal/ipc/stress/internal/server.go
@@ -26,10 +26,10 @@
 	return doSum(arg)
 }
 
-func (s *impl) SumStream(ctx stress.StressSumStreamContext) error {
+func (s *impl) SumStream(call stress.StressSumStreamServerCall) error {
 	defer s.incSumStreamCount()
-	rStream := ctx.RecvStream()
-	sStream := ctx.SendStream()
+	rStream := call.RecvStream()
+	sStream := call.SendStream()
 	for rStream.Advance() {
 		sum, err := doSum(rStream.Value())
 		if err != nil {
diff --git a/profiles/internal/ipc/benchmark/benchmark.vdl.go b/profiles/internal/ipc/benchmark/benchmark.vdl.go
index 69c808b..51be41c 100644
--- a/profiles/internal/ipc/benchmark/benchmark.vdl.go
+++ b/profiles/internal/ipc/benchmark/benchmark.vdl.go
@@ -133,21 +133,21 @@
 	Value() []byte
 	Err() error
 } {
-	return implBenchmarkEchoStreamCallRecv{c}
+	return implBenchmarkEchoStreamClientCallRecv{c}
 }
 
-type implBenchmarkEchoStreamCallRecv struct {
+type implBenchmarkEchoStreamClientCallRecv struct {
 	c *implBenchmarkEchoStreamClientCall
 }
 
-func (c implBenchmarkEchoStreamCallRecv) Advance() bool {
+func (c implBenchmarkEchoStreamClientCallRecv) Advance() bool {
 	c.c.errRecv = c.c.Recv(&c.c.valRecv)
 	return c.c.errRecv == nil
 }
-func (c implBenchmarkEchoStreamCallRecv) Value() []byte {
+func (c implBenchmarkEchoStreamClientCallRecv) Value() []byte {
 	return c.c.valRecv
 }
-func (c implBenchmarkEchoStreamCallRecv) Err() error {
+func (c implBenchmarkEchoStreamClientCallRecv) Err() error {
 	if c.c.errRecv == io.EOF {
 		return nil
 	}
@@ -157,17 +157,17 @@
 	Send(item []byte) error
 	Close() error
 } {
-	return implBenchmarkEchoStreamCallSend{c}
+	return implBenchmarkEchoStreamClientCallSend{c}
 }
 
-type implBenchmarkEchoStreamCallSend struct {
+type implBenchmarkEchoStreamClientCallSend struct {
 	c *implBenchmarkEchoStreamClientCall
 }
 
-func (c implBenchmarkEchoStreamCallSend) Send(item []byte) error {
+func (c implBenchmarkEchoStreamClientCallSend) Send(item []byte) error {
 	return c.c.Send(item)
 }
-func (c implBenchmarkEchoStreamCallSend) Close() error {
+func (c implBenchmarkEchoStreamClientCallSend) Close() error {
 	return c.c.CloseSend()
 }
 func (c *implBenchmarkEchoStreamClientCall) Finish() (err error) {
@@ -179,9 +179,9 @@
 // implements for Benchmark.
 type BenchmarkServerMethods interface {
 	// Echo returns the payload that it receives.
-	Echo(ctx ipc.ServerCall, Payload []byte) ([]byte, error)
+	Echo(call ipc.ServerCall, Payload []byte) ([]byte, error)
 	// EchoStream returns the payload that it receives via the stream.
-	EchoStream(BenchmarkEchoStreamContext) error
+	EchoStream(BenchmarkEchoStreamServerCall) error
 }
 
 // BenchmarkServerStubMethods is the server interface containing
@@ -190,9 +190,9 @@
 // is the streaming methods.
 type BenchmarkServerStubMethods interface {
 	// Echo returns the payload that it receives.
-	Echo(ctx ipc.ServerCall, Payload []byte) ([]byte, error)
+	Echo(call ipc.ServerCall, Payload []byte) ([]byte, error)
 	// EchoStream returns the payload that it receives via the stream.
-	EchoStream(*BenchmarkEchoStreamContextStub) error
+	EchoStream(*BenchmarkEchoStreamServerCallStub) error
 }
 
 // BenchmarkServerStub adds universal methods to BenchmarkServerStubMethods.
@@ -224,12 +224,12 @@
 	gs   *ipc.GlobState
 }
 
-func (s implBenchmarkServerStub) Echo(ctx ipc.ServerCall, i0 []byte) ([]byte, error) {
-	return s.impl.Echo(ctx, i0)
+func (s implBenchmarkServerStub) Echo(call ipc.ServerCall, i0 []byte) ([]byte, error) {
+	return s.impl.Echo(call, i0)
 }
 
-func (s implBenchmarkServerStub) EchoStream(ctx *BenchmarkEchoStreamContextStub) error {
-	return s.impl.EchoStream(ctx)
+func (s implBenchmarkServerStub) EchoStream(call *BenchmarkEchoStreamServerCallStub) error {
+	return s.impl.EchoStream(call)
 }
 
 func (s implBenchmarkServerStub) Globber() *ipc.GlobState {
@@ -290,46 +290,46 @@
 	}
 }
 
-// BenchmarkEchoStreamContext represents the context passed to Benchmark.EchoStream.
-type BenchmarkEchoStreamContext interface {
+// BenchmarkEchoStreamServerCall represents the context passed to Benchmark.EchoStream.
+type BenchmarkEchoStreamServerCall interface {
 	ipc.ServerCall
 	BenchmarkEchoStreamServerStream
 }
 
-// BenchmarkEchoStreamContextStub is a wrapper that converts ipc.StreamServerCall into
-// a typesafe stub that implements BenchmarkEchoStreamContext.
-type BenchmarkEchoStreamContextStub struct {
+// BenchmarkEchoStreamServerCallStub is a wrapper that converts ipc.StreamServerCall into
+// a typesafe stub that implements BenchmarkEchoStreamServerCall.
+type BenchmarkEchoStreamServerCallStub struct {
 	ipc.StreamServerCall
 	valRecv []byte
 	errRecv error
 }
 
-// Init initializes BenchmarkEchoStreamContextStub from ipc.StreamServerCall.
-func (s *BenchmarkEchoStreamContextStub) Init(call ipc.StreamServerCall) {
+// Init initializes BenchmarkEchoStreamServerCallStub from ipc.StreamServerCall.
+func (s *BenchmarkEchoStreamServerCallStub) Init(call ipc.StreamServerCall) {
 	s.StreamServerCall = call
 }
 
 // RecvStream returns the receiver side of the Benchmark.EchoStream server stream.
-func (s *BenchmarkEchoStreamContextStub) RecvStream() interface {
+func (s *BenchmarkEchoStreamServerCallStub) RecvStream() interface {
 	Advance() bool
 	Value() []byte
 	Err() error
 } {
-	return implBenchmarkEchoStreamContextRecv{s}
+	return implBenchmarkEchoStreamServerCallRecv{s}
 }
 
-type implBenchmarkEchoStreamContextRecv struct {
-	s *BenchmarkEchoStreamContextStub
+type implBenchmarkEchoStreamServerCallRecv struct {
+	s *BenchmarkEchoStreamServerCallStub
 }
 
-func (s implBenchmarkEchoStreamContextRecv) Advance() bool {
+func (s implBenchmarkEchoStreamServerCallRecv) Advance() bool {
 	s.s.errRecv = s.s.Recv(&s.s.valRecv)
 	return s.s.errRecv == nil
 }
-func (s implBenchmarkEchoStreamContextRecv) Value() []byte {
+func (s implBenchmarkEchoStreamServerCallRecv) Value() []byte {
 	return s.s.valRecv
 }
-func (s implBenchmarkEchoStreamContextRecv) Err() error {
+func (s implBenchmarkEchoStreamServerCallRecv) Err() error {
 	if s.s.errRecv == io.EOF {
 		return nil
 	}
@@ -337,16 +337,16 @@
 }
 
 // SendStream returns the send side of the Benchmark.EchoStream server stream.
-func (s *BenchmarkEchoStreamContextStub) SendStream() interface {
+func (s *BenchmarkEchoStreamServerCallStub) SendStream() interface {
 	Send(item []byte) error
 } {
-	return implBenchmarkEchoStreamContextSend{s}
+	return implBenchmarkEchoStreamServerCallSend{s}
 }
 
-type implBenchmarkEchoStreamContextSend struct {
-	s *BenchmarkEchoStreamContextStub
+type implBenchmarkEchoStreamServerCallSend struct {
+	s *BenchmarkEchoStreamServerCallStub
 }
 
-func (s implBenchmarkEchoStreamContextSend) Send(item []byte) error {
+func (s implBenchmarkEchoStreamServerCallSend) Send(item []byte) error {
 	return s.s.Send(item)
 }
diff --git a/profiles/internal/ipc/stress/stress.vdl.go b/profiles/internal/ipc/stress/stress.vdl.go
index 90c38f3..c8cd486 100644
--- a/profiles/internal/ipc/stress/stress.vdl.go
+++ b/profiles/internal/ipc/stress/stress.vdl.go
@@ -179,21 +179,21 @@
 	Value() []byte
 	Err() error
 } {
-	return implStressSumStreamCallRecv{c}
+	return implStressSumStreamClientCallRecv{c}
 }
 
-type implStressSumStreamCallRecv struct {
+type implStressSumStreamClientCallRecv struct {
 	c *implStressSumStreamClientCall
 }
 
-func (c implStressSumStreamCallRecv) Advance() bool {
+func (c implStressSumStreamClientCallRecv) Advance() bool {
 	c.c.errRecv = c.c.Recv(&c.c.valRecv)
 	return c.c.errRecv == nil
 }
-func (c implStressSumStreamCallRecv) Value() []byte {
+func (c implStressSumStreamClientCallRecv) Value() []byte {
 	return c.c.valRecv
 }
-func (c implStressSumStreamCallRecv) Err() error {
+func (c implStressSumStreamClientCallRecv) Err() error {
 	if c.c.errRecv == io.EOF {
 		return nil
 	}
@@ -203,17 +203,17 @@
 	Send(item Arg) error
 	Close() error
 } {
-	return implStressSumStreamCallSend{c}
+	return implStressSumStreamClientCallSend{c}
 }
 
-type implStressSumStreamCallSend struct {
+type implStressSumStreamClientCallSend struct {
 	c *implStressSumStreamClientCall
 }
 
-func (c implStressSumStreamCallSend) Send(item Arg) error {
+func (c implStressSumStreamClientCallSend) Send(item Arg) error {
 	return c.c.Send(item)
 }
-func (c implStressSumStreamCallSend) Close() error {
+func (c implStressSumStreamClientCallSend) Close() error {
 	return c.c.CloseSend()
 }
 func (c *implStressSumStreamClientCall) Finish() (err error) {
@@ -225,9 +225,9 @@
 // implements for Stress.
 type StressServerMethods interface {
 	// Do returns the checksum of the payload that it receives.
-	Sum(ctx ipc.ServerCall, arg Arg) ([]byte, error)
+	Sum(call ipc.ServerCall, arg Arg) ([]byte, error)
 	// DoStream returns the checksum of the payload that it receives via the stream.
-	SumStream(StressSumStreamContext) error
+	SumStream(StressSumStreamServerCall) error
 	// GetStats returns the stats on the calls that the server received.
 	GetStats(ipc.ServerCall) (Stats, error)
 	// Stop stops the server.
@@ -240,9 +240,9 @@
 // is the streaming methods.
 type StressServerStubMethods interface {
 	// Do returns the checksum of the payload that it receives.
-	Sum(ctx ipc.ServerCall, arg Arg) ([]byte, error)
+	Sum(call ipc.ServerCall, arg Arg) ([]byte, error)
 	// DoStream returns the checksum of the payload that it receives via the stream.
-	SumStream(*StressSumStreamContextStub) error
+	SumStream(*StressSumStreamServerCallStub) error
 	// GetStats returns the stats on the calls that the server received.
 	GetStats(ipc.ServerCall) (Stats, error)
 	// Stop stops the server.
@@ -278,20 +278,20 @@
 	gs   *ipc.GlobState
 }
 
-func (s implStressServerStub) Sum(ctx ipc.ServerCall, i0 Arg) ([]byte, error) {
-	return s.impl.Sum(ctx, i0)
+func (s implStressServerStub) Sum(call ipc.ServerCall, i0 Arg) ([]byte, error) {
+	return s.impl.Sum(call, i0)
 }
 
-func (s implStressServerStub) SumStream(ctx *StressSumStreamContextStub) error {
-	return s.impl.SumStream(ctx)
+func (s implStressServerStub) SumStream(call *StressSumStreamServerCallStub) error {
+	return s.impl.SumStream(call)
 }
 
-func (s implStressServerStub) GetStats(ctx ipc.ServerCall) (Stats, error) {
-	return s.impl.GetStats(ctx)
+func (s implStressServerStub) GetStats(call ipc.ServerCall) (Stats, error) {
+	return s.impl.GetStats(call)
 }
 
-func (s implStressServerStub) Stop(ctx ipc.ServerCall) error {
-	return s.impl.Stop(ctx)
+func (s implStressServerStub) Stop(call ipc.ServerCall) error {
+	return s.impl.Stop(call)
 }
 
 func (s implStressServerStub) Globber() *ipc.GlobState {
@@ -365,47 +365,47 @@
 	}
 }
 
-// StressSumStreamContext represents the context passed to Stress.SumStream.
-type StressSumStreamContext interface {
+// StressSumStreamServerCall represents the context passed to Stress.SumStream.
+type StressSumStreamServerCall interface {
 	ipc.ServerCall
 	StressSumStreamServerStream
 }
 
-// StressSumStreamContextStub is a wrapper that converts ipc.StreamServerCall into
-// a typesafe stub that implements StressSumStreamContext.
-type StressSumStreamContextStub struct {
+// StressSumStreamServerCallStub is a wrapper that converts ipc.StreamServerCall into
+// a typesafe stub that implements StressSumStreamServerCall.
+type StressSumStreamServerCallStub struct {
 	ipc.StreamServerCall
 	valRecv Arg
 	errRecv error
 }
 
-// Init initializes StressSumStreamContextStub from ipc.StreamServerCall.
-func (s *StressSumStreamContextStub) Init(call ipc.StreamServerCall) {
+// Init initializes StressSumStreamServerCallStub from ipc.StreamServerCall.
+func (s *StressSumStreamServerCallStub) Init(call ipc.StreamServerCall) {
 	s.StreamServerCall = call
 }
 
 // RecvStream returns the receiver side of the Stress.SumStream server stream.
-func (s *StressSumStreamContextStub) RecvStream() interface {
+func (s *StressSumStreamServerCallStub) RecvStream() interface {
 	Advance() bool
 	Value() Arg
 	Err() error
 } {
-	return implStressSumStreamContextRecv{s}
+	return implStressSumStreamServerCallRecv{s}
 }
 
-type implStressSumStreamContextRecv struct {
-	s *StressSumStreamContextStub
+type implStressSumStreamServerCallRecv struct {
+	s *StressSumStreamServerCallStub
 }
 
-func (s implStressSumStreamContextRecv) Advance() bool {
+func (s implStressSumStreamServerCallRecv) Advance() bool {
 	s.s.valRecv = Arg{}
 	s.s.errRecv = s.s.Recv(&s.s.valRecv)
 	return s.s.errRecv == nil
 }
-func (s implStressSumStreamContextRecv) Value() Arg {
+func (s implStressSumStreamServerCallRecv) Value() Arg {
 	return s.s.valRecv
 }
-func (s implStressSumStreamContextRecv) Err() error {
+func (s implStressSumStreamServerCallRecv) Err() error {
 	if s.s.errRecv == io.EOF {
 		return nil
 	}
@@ -413,16 +413,16 @@
 }
 
 // SendStream returns the send side of the Stress.SumStream server stream.
-func (s *StressSumStreamContextStub) SendStream() interface {
+func (s *StressSumStreamServerCallStub) SendStream() interface {
 	Send(item []byte) error
 } {
-	return implStressSumStreamContextSend{s}
+	return implStressSumStreamServerCallSend{s}
 }
 
-type implStressSumStreamContextSend struct {
-	s *StressSumStreamContextStub
+type implStressSumStreamServerCallSend struct {
+	s *StressSumStreamServerCallStub
 }
 
-func (s implStressSumStreamContextSend) Send(item []byte) error {
+func (s implStressSumStreamServerCallSend) Send(item []byte) error {
 	return s.s.Send(item)
 }